@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = 'v0.37.1'; # TRIAL VERSION
+our $VERSION = 'v0.38.2'; # TRIAL VERSION
 
 use YAML::PP::Schema;
 use YAML::PP::Schema::JSON;
@@ -30,6 +30,7 @@ sub new {
     my $writer = delete $args{writer};
     my $header = delete $args{header};
     my $footer = delete $args{footer};
+    my $require_footer = delete $args{require_footer};
     my $duplicate_keys = delete $args{duplicate_keys};
     my $yaml_version = $class->_arg_yaml_version(delete $args{yaml_version});
     my $default_yaml_version = $yaml_version->[0];
@@ -69,6 +70,7 @@ sub new {
         default_yaml_version => $default_yaml_version,
         preserve => $preserve,
         duplicate_keys => $duplicate_keys,
+        require_footer => $require_footer,
     );
     my $dumper = YAML::PP::Dumper->new(
         schema => $default_schema,
@@ -544,8 +546,6 @@ In case of perl 5.36 and later, builtin booleans should work out of the box
 For earlier perl versions, you can use "pseudo" booleans like documented
 in the following examples.
 
-Examples:
-
     # load/dump booleans via boolean.pm
     my $ypp = YAML::PP->new( boolean => 'boolean' );
     # load/dump booleans via JSON::PP::true/false
@@ -573,7 +573,7 @@ This is important for dumping.
     This option is for backwards compatibility for perl versions < 5.36,
     if you rely on [!!1, !1] being dumped as [1, ''].
 
-The option c<perl_experimental> was introduced when experimental boolean
+The option C<perl_experimental> was introduced when experimental boolean
 support was added to perl 5.36. Since it will not be experimental anymore
 in perl 5.40 \o/ the option is deprecated and the same as C<perl>.
 
@@ -669,6 +669,29 @@ This option is for dumping.
 
 Print document footer C<...>
 
+=item require_footer
+
+Default: 0
+
+Will require a C<...> at the end of each document.
+This can be useful in a context where you want to make sure you received
+the complete content, for example over network.
+
+    # Good
+    ---
+    a: 1
+    ...
+    ---
+    a: 2
+    ...
+
+    # Bad
+    ---
+    a: 1
+    ---
+    a: 2
+
+
 =item yaml_version
 
 Since version 0.020
@@ -1031,18 +1054,27 @@ Serializing Perl objects and types
 
 Serializing binary data
 
-=item L<YAML::PP::Schema::Tie::IxHash>
-
-Deprecated. See option C<preserve>
-
 =item L<YAML::PP::Schema::Merge>
 
 YAML 1.1 merge keys for mappings
 
+=item L<YAML::PP::Schema::Catchall>
+
+Experimental.
+
+It was accidentally added in 0.38.1, and unknown tags forbidden.
+This was reverted in 0.39.0
+
+By default they will result in an error.
+
 =item L<YAML::PP::Schema::Include>
 
 Include other YAML files via C<!include> tags
 
+=item L<YAML::PP::Schema::Tie::IxHash>
+
+Deprecated. See option C<preserve>
+
 =back
 
 To make the parsing process faster, you can plugin the libyaml parser
@@ -1297,7 +1329,7 @@ Yes, this can be enabled optionally, see L<YAML::PP::Schema::Merge>
 
 =item Is there a linter / formatter for YAML
 
-There is the widely L<"yamllint"|https://yamllint.readthedocs.io/>, based on
+There is the widely used L<"yamllint"|https://yamllint.readthedocs.io/>, based on
 python's PyYAML. It is very configurable and will report errors or warnings.
 It cannot format.
 
